==> apache-geode-1.12.7-src.tgz: apache-geode-1.12.7-src/geode-lucene/geode-lucene-test/src/main/java/org/apache/geode/cache/lucene/test/Customer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.cache.lucene.test;

import java.io.Serializable;
import java.util.Collection;

public class Customer implements Serializable {
  protected String name;
  protected Collection<String> phoneNumbers;
  protected Collection<Person> contacts;
  protected Page[] myHomePages;

  public Customer(String name, Collection<String> phoneNumbers, Collection<Person> contacts,
      Page[] myHomePages) {
    this.name = name;
    this.phoneNumbers = phoneNumbers;
    this.contacts = contacts;
    this.myHomePages = myHomePages;
  }

  public void addContact(Person contact) {
    this.contacts.add(contact);
  }

  @Override
  public String toString() {
    return this.getClass() + "[name=" + name + ",phoneNumbers=" + phoneNumbers + ",contacts="
        + contacts
        + ",homepage=" + myHomePages + "]";
  }
}

==> apache-geode-1.15.2-src.tgz: apache-geode-1.15.2-src/geode-lucene/geode-lucene-test/src/main/java/org/apache/geode/cache/lucene/test/Customer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.cache.lucene.test;

import java.io.Serializable;
import java.util.Collection;

public class Customer implements Serializable {
  protected String name;
  protected Collection<String> phoneNumbers;
  protected Collection<Person> contacts;
  protected Page[] myHomePages;

  public Customer(String name, Collection<String> phoneNumbers, Collection<Person> contacts,
      Page[] myHomePages) {
    this.name = name;
    this.phoneNumbers = phoneNumbers;
    this.contacts = contacts;
    this.myHomePages = myHomePages;
  }

  public void addContact(Person contact) {
    contacts.add(contact);
  }

  @Override
  public String toString() {
    return getClass() + "[name=" + name + ",phoneNumbers=" + phoneNumbers + ",contacts="
        + contacts
        + ",homepage=" + myHomePages + "]";
  }
}
